@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Manipulate the position of notes in a scale
 
-our $VERSION = '0.03';
+our $VERSION = '0.0301';
 
 use Carp;
 use Moo;
@@ -74,6 +74,9 @@ sub get_offset {
             if $self->verbose;
         $args{offset} += $posn;
     }
+    else {
+        warn "Scale position not defined!\n";
+    }
 
     my $octave = $note->octave;
     my $factor = int( $args{offset} / @scale );
@@ -84,8 +87,6 @@ sub get_offset {
     else {
         $octave += $factor;
     }
-    croak "Octave: $octave out of bounds"
-        if $octave < 0 or $octave > 127;
 
     $note = Music::Note->new( $scale[ $args{offset} % @scale ] . $octave, 'ISO' );
     warn sprintf "\tNew offset: %d, ISO: %s, Formatted: %s\n",
@@ -109,7 +110,7 @@ Music::ScaleNote - Manipulate the position of notes in a scale
 
 =head1 VERSION
 
-version 0.03
+version 0.0301
 
 =head1 SYNOPSIS
 
